AsyncGuardAdapterBuilder

Struct AsyncGuardAdapterBuilder 

pub struct AsyncGuardAdapterBuilder<E>
where E: ExternalGuard + ?Sized,
{ /* private fields */ }
Fluent builder for AsyncGuardAdapter.

Implementations

Source

impl<E> AsyncGuardAdapterBuilder<E>
where E: ExternalGuard + ?Sized,

pub fn new(inner: Arc<E>) -> AsyncGuardAdapterBuilder<E>

Start from the given guard and default configuration.

pub fn circuit( self, circuit: CircuitBreakerConfig, ) -> AsyncGuardAdapterBuilder<E>

Override the circuit breaker configuration.

pub fn retry(self, retry: RetryConfig) -> AsyncGuardAdapterBuilder<E>

Override retry configuration.

pub fn cache_capacity( self, capacity: NonZero<usize>, ) -> AsyncGuardAdapterBuilder<E>

Set the cache capacity (non-zero).

pub fn cache_ttl(self, ttl: Duration) -> AsyncGuardAdapterBuilder<E>

Set the cache TTL.

pub fn rate_limit( self, rate_per_second: f64, burst: u32, ) -> AsyncGuardAdapterBuilder<E>

Set the rate limiter (calls per second + burst).

pub fn circuit_open_verdict( self, verdict: CircuitOpenVerdict, ) -> AsyncGuardAdapterBuilder<E>

Set the verdict returned while the breaker is open.

pub fn rate_limited_verdict( self, verdict: RateLimitedVerdict, ) -> AsyncGuardAdapterBuilder<E>

Set the verdict returned when the rate limiter rejects a call.

pub fn clock(self, clock: Arc<dyn Clock>) -> AsyncGuardAdapterBuilder<E>

Override the time source. Primarily for tests.

pub fn build(self) -> AsyncGuardAdapter<E>

Finalize the builder.